List supported attributes
Arguments
- ...
Ignored. Used to catch no longer necessary parameters from the
biomaRt functions.
Value
A character vector of supported attributes to be used in getBM()
and getLDS().
Examples
listAttributes()
#> [1] "chromosome_name" "description" "end_position"
#> [4] "ensembl_gene_id" "ensembl_peptide_id" "ensembl_transcript_id"
#> [7] "external_gene_name" "gene_biotype" "hgnc_symbol"
#> [10] "start_position" "strand" "transcript_biotype"
#> [13] "version"